@@ -7,8 +7,8 @@
 ;;             Jen-Chieh Shen <jcs090218@gmail.com>
 ;; URL: http://github.com/ardumont/markdown-toc
 ;; Created: 24th May 2014
-;; Package-Version: 20251210.2018
-;; Package-Revision: 29e5c0f33ed0
+;; Package-Version: 20260131.1444
+;; Package-Revision: d22633b65419
 ;; Keywords: markdown, toc, tools,
 ;; Package-Requires: ((emacs "28.1") (markdown-mode "2.1") (dash "2.11.0") (s "1.9.0"))
 
@@ -66,7 +66,9 @@
 (require 'markdown-mode)
 (require 'find-func) ; find-library-name
 
-(defconst markdown-toc--toc-version "0.1.5" "Current version installed.")
+(require 'markdown-toc-pandoc)
+
+(defconst markdown-toc--toc-version "0.1.6" "Current version installed.")
 
 (defgroup markdown-toc nil
   "A simple TOC generator for markdown file."
@@ -134,6 +136,18 @@ Default to identity function (do nothing)."
   :group 'markdown-toc
   :type 'function)
 
+(defcustom markdown-toc-preset 'legacy
+  "The algorithm preset for the markdown toc generator.
+
+The default uses the `legacy' algorithm originated from this package.
+
+Set to the symbol `pandoc' to compatible with pandoc html export and
+with Unicode support."
+  :group 'markdown-toc
+  :type '(choice (const :tag "Legacy" legacy)
+                 (const :tag "Pandoc" pandoc)
+                 (const :tag "Pandoc CLI" pandoc-cli)))
+
 (defun markdown-toc-log-msg (args)
   "Log message ARGS."
   (apply #'message (format "markdown-toc - %s" (car args)) (cdr args)))
@@ -207,7 +221,7 @@ TOC-STRUCTURE is a list of cons cells, where each cons cell contains:
                     (list indent title (- count 1))))
                 toc-structure))
 
-(defun markdown-toc--to-markdown-toc (level-title-toc-list)
+(defun markdown-toc--to-markdown-toc-legacy (level-title-toc-list)
   "Given LEVEL-TITLE-TOC-LIST, a list of pair level, title, return a TOC string."
   (->> level-title-toc-list
        markdown-toc--count-duplicate-titles
@@ -220,6 +234,14 @@ TOC-STRUCTURE is a list of cons cells, where each cons cell contains:
                         (markdown-toc--to-link title count))))
        (s-join "\n")))
 
+(defun markdown-toc--to-markdown-toc (level-title-toc-list)
+  "Dispatcher for generating TOC string."
+  (funcall (pcase markdown-toc-preset
+             (`pandoc     #'markdown-toc--to-markdown-toc-pandoc)
+             (`pandoc-cli #'markdown-toc--to-markdown-toc-pandoc-cli)
+             (_           #'markdown-toc--to-markdown-toc-legacy))
+           level-title-toc-list))
+
 (defun markdown-toc--toc-already-present-p ()
   "Determine if a TOC has already been generated.
 Return the end position if it exists, nil otherwise."
@@ -227,7 +249,6 @@ Return the end position if it exists, nil otherwise."
     (goto-char (point-min))
     (re-search-forward markdown-toc-header-toc-start nil t)))
 
-
 (defun markdown-toc--toc-start ()
   "Compute the toc's starting point."
   (save-excursion
